@@ -40,7 +40,7 @@
 #include "gnome-i18nP.h"
 
 #include "gnome-init.h"
-#include "gnome-gconf.h"
+#include "gnome-gconfP.h"
 #include "gnome-util.h"
 #include "gnome-sound.h"
 #include "gnome-triggers.h"
@@ -72,6 +72,17 @@ bonobo_post_args_parse (GnomeProgram *program, GnomeModuleInfo *mod_info)
 	bonobo_init (&dumb_argc, dumb_argv);
 }
 
+/**
+* gnome_bonobo_module_info_get:
+*
+* Retrieves the bonobo module version and indicate that it requires the current
+* libgnome and its dependencies (although libbonobo does not depend on
+* libgnome, libbonoboui does and this will also be initialised when
+* initialising a GNOME app).
+*
+* Returns: a new #GnomeModuleInfo structure describing the version of the
+* bonobo modules and its dependents.
+*/
 const GnomeModuleInfo *
 gnome_bonobo_module_info_get (void)
 {
@@ -154,18 +165,41 @@ static char *gnome_user_dir = NULL;
 static char *gnome_user_private_dir = NULL;
 static char *gnome_user_accels_dir = NULL;
 
+/**
+* gnome_user_dir_get:
+*
+* Returns: An absolute path to the user-specific directory for GNOME apps to
+* use.
+*/
 const char *
 gnome_user_dir_get (void)
 {
 	return gnome_user_dir;
 }
 
+/**
+* gnome_user_private_dir_get:
+*
+* Differs from gnome_user_dir_get() in that the directory returned here will
+* have had permissions of 0700 (rwx------) enforced when it was created.  Of
+* course, the permissions may have been altered since creation, so care still
+* needs to be taken.
+*
+* Returns: An absolute path to the user-specific private directory that GNOME
+* apps can use.
+*/
 const char *
 gnome_user_private_dir_get (void)
 {
 	return gnome_user_private_dir;
 }
 
+/**
+* gnome_user_accels_dir_get:
+*
+* Returns: The absolute path to the user-specific directory that stores the
+* keyboard shortcut files for each GNOME app.
+*/
 const char *
 gnome_user_accels_dir_get (void)
 {
@@ -226,10 +260,11 @@ static void
 libgnome_userdir_setup (gboolean create_dirs)
 {
 	if(!gnome_user_dir) {
-		gnome_user_dir = g_concat_dir_and_file (g_get_home_dir(), ".gnome");
-		gnome_user_private_dir = g_concat_dir_and_file (g_get_home_dir(),
-								".gnome_private");
-		gnome_user_accels_dir = g_concat_dir_and_file (gnome_user_dir, "accels");
+		gnome_user_dir = g_build_filename (g_get_home_dir(), ".gnome", NULL);
+		gnome_user_private_dir = g_build_filename (g_get_home_dir(),
+							   ".gnome_private", NULL);
+		gnome_user_accels_dir = g_build_filename (gnome_user_dir,
+							  "accels", NULL);
 	}
 
 	if (!create_dirs)
@@ -326,8 +361,8 @@ static struct poptOption gnomelib_options [] = {
 	  NULL, ARG_ENABLE_SOUND, N_("Enable sound server usage"), NULL},       
 
 	{ "espeaker", '\0', POPT_ARG_STRING,                                    
-	  NULL, ARG_ESPEAKER, N_("Host:port on which the sound server to use is 
-				 running"),
+	  NULL, ARG_ESPEAKER, N_("Host:port on which the sound server to use is"
+				 " running"),
 	  N_("HOSTNAME:PORT")},                                                 
 
 	{"version", '\0', POPT_ARG_NONE, NULL, },
@@ -355,7 +390,14 @@ gnome_vfs_module_info_get (void)
 	};
 	return &module_info;
 }
-
+/**
+* libgnome_module_info_get:
+* 
+* Retrieves the current libgnome version and the modules it depends on.
+*
+* Returns: a new #GnomeModuleInfo structure describing the version and
+* the versions of the dependents.
+*/
 const GnomeModuleInfo *
 libgnome_module_info_get (void)
 {
