@@ -30,6 +30,8 @@
    initialization and command line parsing */
 
 #include <config.h>
+#include "gnome-macros.h"
+
 #include <ctype.h>
 #include <stdio.h>
 #include <stdlib.h>
@@ -39,11 +41,11 @@
 
 #include "gnome-i18nP.h"
 
-#include <libgnome/gnome-program.h>
-#include <libgnome/gnome-util.h>
-#include <libgnome/gnome-init.h>
-#include <libgnome/gnome-i18n.h>
-#include <libgnome/gnome-url.h>
+#include "gnome-program.h"
+#include "gnome-util.h"
+#include "gnome-init.h"
+#include "gnome-i18n.h"
+#include "gnome-url.h"
 
 #include <gobject/gboxed.h>
 #include <gobject/gvaluearray.h>
@@ -135,35 +137,12 @@ static gboolean program_initialized = FALSE;
 static GnomeProgram *global_program = NULL;
 
 static guint last_property_id = PROP_LAST;
-static gpointer parent_class = NULL;
 
 #define	PREALLOC_CPARAMS (8)
 #define	PREALLOC_MODINFOS (8)
 
-GType
-gnome_program_get_type (void)
-{
-    static GType program_type = 0;
-
-    if (!program_type) {
-	static const GTypeInfo program_info = {
-	    sizeof (GnomeProgramClass),
-	    (GBaseInitFunc)         NULL,
-	    (GBaseFinalizeFunc)     NULL,
-	    (GClassInitFunc)        gnome_program_class_init,
-	    NULL,                   /* class_finalize */
-	    NULL,                   /* class_data */
-	    sizeof (GnomeProgram),
-	    0,                      /* n_preallocs */
-	    (GInstanceInitFunc)     gnome_program_instance_init
-	};
-
-	program_type = g_type_register_static
-	    (G_TYPE_OBJECT, "GnomeProgram", &program_info, 0);
-    }
-
-    return program_type;
-}
+GNOME_CLASS_BOILERPLATE (GnomeProgram, gnome_program,
+			 GObject, g_object, G_TYPE_OBJECT)
 
 static void
 gnome_program_set_property (GObject *object, guint param_id,
@@ -348,7 +327,7 @@ add_to_module_list (GPtrArray *module_list, const gchar *module_name)
     modnames = g_strsplit (module_name, ",", -1);
     for (i = 0; modnames && modnames[i]; i++) {
 	for (j = 0; j < module_list->len; j++)
-	    if (strcmp (modnames[i], g_ptr_array_index (module_list, j)) == 0)
+	    if (strcmp (modnames[i], (char *) g_ptr_array_index (module_list, j)) == 0)
 		return;
 
 	g_ptr_array_add (module_list, g_strdup (modnames[i]));
@@ -654,11 +633,13 @@ gnome_program_finalize (GObject* object)
 	(* G_OBJECT_CLASS (parent_class)->finalize) (object);
 }
 
+/* UNUSED
 static gpointer
 gnome_module_info_init (void)
 {
     return g_new0 (GnomeModuleInfo, 1);
 }
+*/
 
 static gpointer
 gnome_module_info_copy (gpointer boxed)
@@ -678,10 +659,9 @@ gnome_module_info_get_type (void)
     static GType module_info_type = 0;
 
     if (!module_info_type)
-	module_info_type = g_boxed_type_register_static
-	    ("GnomeModuleInfo", gnome_module_info_init,
-	     gnome_module_info_copy, gnome_module_info_free,
-	     FALSE);
+	module_info_type = g_boxed_type_register_static	("GnomeModuleInfo",
+		 gnome_module_info_copy, gnome_module_info_free);
+
 
     return module_info_type;
 }
@@ -689,10 +669,10 @@ gnome_module_info_get_type (void)
 /**
  * gnome_program_get:
  *
- * Returns: an object that stores information on the GNOME application's state.
- * If the object does not exist, %NULL is returned.
- * Other functions assume that this will always return an appobject
- * with state > APP_UNINIT
+ * Returns: An object that stores information on the GNOME application's state.
+ * If the object does not exist, %NULL is returned. Other functions assume that
+ * this will always return a #GnomeProgram object which (if not %NULL) has
+ * already been initialized.
  */
 
 GnomeProgram *
@@ -711,7 +691,7 @@ gnome_program_get (void)
  * human-readable identifier so much as a unique identifier for
  * programs and libraries.
  *
- * Returns: application ID string.
+ * Returns: Application ID string.
  */
 const char *
 gnome_program_get_app_id (GnomeProgram *program)
@@ -725,7 +705,7 @@ gnome_program_get_app_id (GnomeProgram *program)
 
 /**
  * gnome_program_get_app_version
- * @app: The application object
+ * @program: The application object
  *
  * Description:
  * This function returns a pointer to a static string that the
@@ -733,7 +713,7 @@ gnome_program_get_app_id (GnomeProgram *program)
  * human-readable identifier so much as a unique identifier for
  * programs and libraries.
  *
- * Returns: application version string.
+ * Returns: Application version string.
  */
 const char *
 gnome_program_get_app_version (GnomeProgram *program)
@@ -747,15 +727,15 @@ gnome_program_get_app_version (GnomeProgram *program)
 
 /**
  * gnome_program_get_human_readable_name
- * @app: The application object
+ * @program: The application object
  *
  * Description:
  * This function returns a pointer to a static string that the
  * application has provided as a human readable name. The app
- * should provide the name with the GNOME_PARAM_HUMAN_READABLE_NAME
- * init argument. Returns NULL if no name was set.
+ * should provide the name with the #GNOME_PARAM_HUMAN_READABLE_NAME
+ * init argument. Returns %NULL if no name was set.
  *
- * Returns: application human-readable name string.
+ * Returns: Application human-readable name string.
  */
 const char *
 gnome_program_get_human_readable_name (GnomeProgram *program)
@@ -788,8 +768,10 @@ gnome_program_install_property (GnomeProgramClass *pclass,
 
 /**
  * gnome_program_locate_file:
- * @domain: A domain (see GnomeFileDomain in gnome-program.h).
- * @filename: A file name or path inside the 'domain' to find.
+ * @program: A valid #GnomeProgram object or %NULL (in which case the current
+ * application is used).
+ * @domain: A #GnomeFileDomain.
+ * @file_name: A file name or path inside the 'domain' to find.
  * @only_if_exists: Only return a full pathname if the specified file
  *                  actually exists
  * @ret_locations: If this is not %NULL, a list of all the possible locations
@@ -799,16 +781,16 @@ gnome_program_install_property (GnomeProgramClass *pclass,
  * "domain". A domain is a name for a collection of related files.
  * For example, common domains are "libdir", "pixmap", and "config".
  *
- * If @ret_locations is not %NULL, there is no other return value.  That is
- * this function then always returns %NULL.
+ * If @ret_locations is %NULL, there is no other return value.
  *
- * The _APP_ domains are ones for your own application.  However you MUST
- * set the correct attributes for GnomeProgram for the APP specific prefixes.
+ * The GNOME_FILE_DOMAIN_APP_* domains are ones for your own application.
+ * However you MUST set the correct attributes for #GnomeProgram for the APP
+ * specific prefixes (during the initialization part of the application).
  *
  * The @ret_locations list and its contents should be freed by the caller.
  *
  * Returns: The full path to the file (if it exists or only_if_exists is
- *          FALSE) or NULL.
+ *          %FALSE) or %NULL.
  */
 gchar *
 gnome_program_locate_file (GnomeProgram *program, GnomeFileDomain domain,
@@ -1118,9 +1100,9 @@ gnome_program_module_registered (const GnomeModuleInfo *module_info)
  *
  * Description:
  * This function is used to register a module to be initialized by the
- * GNOME library framework. The memory pointed to by 'module_info' must be
+ * GNOME library framework. The memory pointed to by @module_info must be
  * valid during the whole application initialization process, and the module
- * described by 'module_info' must only use the 'module_info' pointer to
+ * described by @module_info must only use the @module_info pointer to
  * register itself.
  *
  */
@@ -1420,17 +1402,17 @@ gnome_program_postinit (GnomeProgram *program)
 
 /**
  * gnome_program_init:
- * @app_id: Application ID string
- * @app_version: Application version string
- * @module_info: The module to init with this program
- * @argc: The number of commmand line arguments contained in 'argv'
- * @argv: A string array of command line arguments
- * @...: a NULL-terminated list of attribute name/value pairs
+ * @app_id: Application ID string.
+ * @app_version: Application version string.
+ * @module_info: The module to init with this program.
+ * @argc: The number of commmand line arguments contained in @argv.
+ * @argv: A string array of command line arguments.
+ * @first_property_name: The first item in a %NULL-terminated list of attribute
+ * name/value.
+ * @...: The continuation of a %NULL-terminated list of attribute name/value
+ * pairs.
  *
- * Description:
- * Performs application initialization.  It will load the specified
- * @module_info, which is normally LIBGNOME_MODULE or LIBGNOMEUI_MODULE
- * and it pulls in all the dependencies
+ * Returns: A #GnomeProgram instance representing the current application.
  */
 GnomeProgram *
 gnome_program_init (const char *app_id, const char *app_version,
@@ -1452,7 +1434,26 @@ gnome_program_init (const char *app_id, const char *app_version,
     return program;
 }
 
-GnomeProgram *
+/**
+ * gnome_program_initv:
+ * @type: The type of application to be initialized (usually
+ * #GNOME_TYPE_PROGRAM).
+ * @app_id: Application ID string.
+ * @app_version: Application version string.
+ * @module_info: The modules to init with the application.
+ * @argc: The number of command line arguments contained in @argv.
+ * @argv: A string array of command line arguments.
+ * @first_property_name: The first item in a %NULL-terminated list of attribute
+ * name/value.
+ * @args: The remaining elements in the %NULL terminated list (of which
+ * @first_property_name is the first element).
+ *
+ * Provides a non-varargs form of gnome_program_init(). Users will rarely need
+ * to call this function directly.
+ *
+ * Returns: A #GnomeProgram instance representing the current application.
+ */
+GnomeProgram*
 gnome_program_initv (GType type,
 		     const char *app_id, const char *app_version,
 		     const GnomeModuleInfo *module_info,
@@ -1583,8 +1584,8 @@ gnome_program_initv (GType type,
 	}
     }
 
-    program = g_object_new_valist (type,
-				   first_property_name, args);
+    program = (GnomeProgram *)g_object_new_valist (type,
+						   first_property_name, args);
 
     if (!program_initialized) {
 	global_program = program;
