@@ -35,6 +35,8 @@
 #include <stdlib.h>
 #include <string.h>
 #include <glib.h>
+#include <pwd.h>
+#include <ctype.h>
 #include <locale.h>
 #ifdef HAVE_SYS_FSUID_H
 #ifdef HAVE_SETFSGID
@@ -118,7 +120,7 @@ log_score (const gchar * progname, const gchar * level, gchar * username,
 {
    FILE *infile;
    FILE *outfile;
-   gchar buf[512], *buf2;
+   gchar buf[512], name[512];
    GList *scores = NULL, *anode;
    gchar *game_score_file;
    gfloat ascore;
@@ -138,25 +140,15 @@ log_score (const gchar * progname, const gchar * level, gchar * username,
 	 {
 	     long ltime;
 	     i = strlen (buf) - 1;	/* Chomp */
-	     while (g_ascii_isspace (buf[i]))
+	     while (isspace (buf[i]))
 	       buf[i--] = '\0';
 
-  	     {
-	        char *tokp;
-
-	        if((buf2 = strtok_r (buf, " ", &tokp)) == NULL)
-		  break;
-	        ascore = atof (buf2);
-	        if((buf2 = strtok_r (NULL, " ", &tokp)) == NULL)
-		  break;
-	        ltime = atoi (buf2);
-	        if((buf2 = strtok_r (NULL, "\n", &tokp)) == NULL)
-		  break;
-	     }
+	     if(sscanf(buf, "%f %ld %s", &ascore, &ltime, name) != 3)
+	       break;
 
 	     anitem = g_new(struct ascore_t, 1);
 	     anitem->score = ascore;
-	     anitem->username = g_strdup (buf2);
+	     anitem->username = g_strdup (name);
 	     anitem->scoretime = (time_t)ltime;
 	     scores = g_list_append (scores, (gpointer) anitem);
 	  }
@@ -228,7 +220,7 @@ gnome_score_child (void)
 {
    struct command cmd;
    gchar *level;
-   gchar *realname;
+   struct passwd *pwd;
    gint retval;
 #ifdef HAVE_SETFSGID
    gid_t gid;
@@ -237,9 +229,7 @@ gnome_score_child (void)
    setgid (getgid ());
    setfsgid (gid);
 #endif
-   realname = g_strdup (g_get_real_name ());
-   if (strlen (realname) == 0)
-     realname = g_strdup (g_get_user_name ());
+   pwd = getpwuid (getuid ());
 
    while (read (STDIN_FILENO, &cmd, sizeof cmd) == sizeof(cmd))
      {
@@ -250,15 +240,13 @@ gnome_score_child (void)
 	   g_free(level);
 	   level = NULL;
 	}
-	retval = log_score (defgamename, level, realname, cmd.score,
+	retval = log_score (defgamename, level, pwd->pw_name, cmd.score,
 			    cmd.ordering);
 	if (write(STDOUT_FILENO, &retval, sizeof retval) != sizeof retval)
 	  return EXIT_FAILURE;
 	if (level)
 	  g_free(level);
      }
-   if (realname)
-     g_free (realname);
    return EXIT_SUCCESS;
 }
 
@@ -286,12 +274,12 @@ drop_perms (void)
  * gnome_score_init:
  * @gamename: Identifies the game name.
  *
- * GNOME games should call this routine as the first statement
- * in main() if they have been installed setgid to the "games" group. It
- * performs the intialization required to later record information in the
- * scores table and then drops the groups privileges.
+ * GNOME Games should call this routine as the first statement
+ * in main () if they have been installed setgid to the games() group.
  * 
- * Returns: %0 on success, returns %-1 on failure.
+ * Returns: 0 on success, returns -1 on failure.
+ *
+ * group privileges are dropped regardless of the status returned.
  */
 
 gint
@@ -348,16 +336,13 @@ gnome_score_init (const gchar * gamename)
 
 /**
  * gnome_score_log:
- * @score: The score achieved by the user in this game
- * @level: The level on which the score was obtained
- * @higher_to_lower_score_order: Set to %TRUE if high scores are better than
- * low scores.
+ * @score: the score achieved by the user in this game
+ * @level: level on which the score was obtained
+ * @higher_to_lower_score_order: biggers is better or not
  *
- * Logs a score entry for the user. You should call this every time a game
- * ends.  This function takes care of working out whether the user's score made
- * it into the ten best scores and, if so, records it in the table.
+ * Logs a score entry for the user.
  *
- * Returns: %0 on failure or the status from the gnome-score helper
+ * Returns 0 on failure or the status from the gnome-score helper
  * program.
  */
 gint
@@ -396,17 +381,16 @@ gnome_score_log (gfloat score,
 
 /**
  * gnome_score_get_notable:
- * @gamename:   The name of the game we want to fetch information from.
- * @level:      The level for which we want to pull information.
- * @names:      An array of strings is returned at the address pointed here
- * @scores:     An array of gfloats is returned at the address pointed here
- * @scoretimes: An array of time_t is returned at the address pointed here
+ * @gamename:   the name of the game we want to fetch information from.
+ * @level:      the level from which we want to pull information.
+ * @names:      an array of strings is returned at the address pointed here
+ * @scores:     an array of gfloats is returned at the address pointed here
+ * @scoretimes: an array of time_t is returned at the address pointed here
  *
  * Fetches the most notable players on @gamename at level @level.
  *
- * Returns: the number of scores returned.  The @names, @scores and @scoretime
- * pointers point to regions that were allocated with g_malloc() with the
- * contents.
+ * Returns the number of scores returned.  @names, @scores and @scoretime
+ * point to regions that were allocated with g_malloc() with the contents.
  */
 gint
 gnome_score_get_notable (const gchar * gamename,
